@@ -1,4 +1,4 @@
-from taurus.qt import Qt
+from taurus.external.qt import Qt
 from taurus.qt.qtgui.resource import getThemeIcon
 
 class MyGUI(Qt.QMainWindow):
