@@ -2,9 +2,9 @@
 
 #############################################################################
 ##
-## This file is part of Taurus, a Tango User Interface Library
+## This file is part of Taurus
 ##
-## http://www.tango-controls.org/static/taurus/latest/doc/html/index.html
+## http://taurus-scada.org
 ##
 ## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
 ##
@@ -184,7 +184,7 @@ class TangoAttribute(TaurusAttribute):
                 attrvalue = float(value)
             elif type == DataType.DevFloat:
                 # We encode to float, but rounding to Tango::DevFloat precision
-                # see: http://sf.net/p/sardana/tickets/162
+                # see: http://sf.net/p/tauruslib/tickets/61
                 attrvalue = float(numpy.float32(value))
             elif PyTango.is_int_type(type):
                 #attrvalue = int(value)
@@ -196,7 +196,7 @@ class TangoAttribute(TaurusAttribute):
                     attrvalue = str(value).lower() == 'true'
             elif type == DataType.DevUChar:
                 attrvalue = chr(value)
-            elif type == DataType.DevState:
+            elif type == DataType.DevState or type == DataType.DevEncoded:
                 attrvalue = value
             else:
                 attrvalue = str(value)
