@@ -1,41 +1,24 @@
-#!/usr/bin/env python
-
 #############################################################################
 ##
-## This file is part of Taurus, a Tango User Interface Library
-## 
-## http://www.tango-controls.org/static/taurus/latest/doc/html/index.html
+## This file is part of Taurus
+##
+## http://taurus-scada.org
 ##
 ## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
-## 
+##
 ## Taurus is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU Lesser General Public License as published by
 ## the Free Software Foundation, either version 3 of the License, or
 ## (at your option) any later version.
-## 
+##
 ## Taurus is distributed in the hope that it will be useful,
 ## but WITHOUT ANY WARRANTY; without even the implied warranty of
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU Lesser General Public License for more details.
-## 
+##
 ## You should have received a copy of the GNU Lesser General Public License
 ## along with Taurus.  If not, see <http://www.gnu.org/licenses/>.
 ##
 #############################################################################
 
-"""This package contains a collection of taurus widgets designed to connect
-to sardana"""
-
-__docformat__ = 'restructuredtext'
-
-from .measurementgroup import *
-from .expdescription import *
-from .elementtree import *
-
-try:
-    from .sardanaeditor import *
-except:
-    from taurus.qt.qtgui.display import create_taurus_fallback as __create
-    SardanaEditor = __create("SardanaEditor")
-
-
+from sardana.taurus.qt.qtgui.extra_sardana import *
