@@ -2,9 +2,9 @@
 
 #############################################################################
 ##
-## This file is part of Taurus, a Tango User Interface Library
+## This file is part of Taurus
 ## 
-## http://www.tango-controls.org/static/taurus/latest/doc/html/index.html
+## http://taurus-scada.org
 ##
 ## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
 ## 
@@ -947,6 +947,10 @@ def taurusFormMain():
     dialog.setModifiableByUser(True)
     dialog.setModelInConfig(True)
     dialog.setWindowTitle(options.window_name)
+
+    # Make sure the window size and position are restored
+    dialog.registerConfigProperty(dialog.saveGeometry, dialog.restoreGeometry,
+                                  'MainWindowGeometry')
             
     from taurus.qt.qtgui.resource import getThemeIcon
     quitApplicationAction =  Qt.QAction(getThemeIcon("process-stop"),'Close Form', dialog)
