@@ -2,9 +2,9 @@
 
 #############################################################################
 ##
-## This file is part of Taurus, a Tango User Interface Library
+## This file is part of Taurus
 ## 
-## http://www.tango-controls.org/static/taurus/latest/doc/html/index.html
+## http://taurus-scada.org
 ##
 ## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
 ## 
@@ -173,6 +173,7 @@ class TaurusArrayEditor(TaurusWidget):
         
         :return: (dict) a map with pertinent designer information"""
         ret = TaurusWidget.getQtDesignerPluginInfo()
+        ret['module'] = 'taurus.qt.qtgui.plot'
         ret['group'] = 'Taurus Input'
         ret['icon'] =':/designer/arrayedit.png'
         ret['container'] = False
