@@ -56,7 +56,7 @@ ORGANIZATION = 'Taurus'
 # You can provide an URI for a manual in html format
 # (comment out or make MANUAL_URI=None to skip creating a Manual panel) 
 #===============================================================================
-MANUAL_URI = 'http://packages.python.org/taurus'
+MANUAL_URI = 'http://www.taurus-scada.org'
 
 #===============================================================================
 # If you want to have a main synoptic panel, set the SYNOPTIC variable
@@ -173,4 +173,4 @@ EXTRA_CATALOG_WIDGETS = [('PyQt4.Qt.QLineEdit',':/taurus.png'),  # a resource
 # Possible items for console are 'ipython', 'tango', 'spock'
 # Note: This is still experimental
 #===============================================================================
-#CONSOLE = ['tango']
\ No newline at end of file
+#CONSOLE = ['tango']
