@@ -2,9 +2,9 @@
 
 #############################################################################
 ##
-## This file is part of Taurus, a Tango User Interface Library
+## This file is part of Taurus
 ##
-## http://www.tango-controls.org/static/taurus/latest/doc/html/index.html
+## http://taurus-scada.org
 ##
 ## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
 ##
@@ -121,6 +121,11 @@ class DynamicPlotManager(Qt.QObject, TaurusBaseComponent):
         '''
         if expconf['ActiveMntGrp'] is None:
             return
+        if expconf['ActiveMntGrp'] not in expconf['MntGrpConfigs'].keys():
+            self.warning(
+                "ActiveMntGrp '%s' is not defined" %
+                expconf['ActiveMntGrp'])
+            return
         mgconfig = expconf['MntGrpConfigs'][expconf['ActiveMntGrp']]
         channels = dict(getChannelConfigs(mgconfig, sort=False))
         
