@@ -2,9 +2,9 @@
 
 #############################################################################
 ##
-## This file is part of Taurus, a Tango User Interface Library
+## This file is part of Taurus
 ## 
-## http://www.tango-controls.org/static/taurus/latest/doc/html/index.html
+## http://taurus-scada.org
 ##
 ## Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
 ## 
@@ -32,7 +32,7 @@ __docformat__ = 'restructuredtext'
 import os
 import xml.dom.minidom
 
-from taurus.qt import Qt
+from taurus.external.qt import Qt
 from taurus.qt.qtcore.configuration import BaseConfigurableClass
 from taurus.qt.qtgui.resource import getThemeIcon
 
@@ -74,7 +74,7 @@ class ExternalAppAction(Qt.QAction, BaseConfigurableClass):
         self.setToolTip("Launches %s (external application)"%text)
         self.registerConfigProperty(self.cmdArgs, self.setCmdArgs, 'cmdArgs')
     
-    def setCmdArgs(self, cmdargs):
+    def setCmdArgs(self, cmdargs, emitsignal=True):
         '''Sets the command args for executing this external application.
         
         It emits the "cmdArgsChanged" signal with the new cmdArgs list 
@@ -88,7 +88,8 @@ class ExternalAppAction(Qt.QAction, BaseConfigurableClass):
             import shlex
             cmdargs = shlex.split(str(cmdargs))
         self.__cmdargs = cmdargs
-        self.emit(Qt.SIGNAL("cmdArgsChanged"), self.__cmdargs)
+        if emitsignal:
+            self.emit(Qt.SIGNAL("cmdArgsChanged"), self.__cmdargs)
         
     def cmdArgs(self):
         return self.__cmdargs
@@ -232,10 +233,10 @@ class AttributeAllConfigAction(TaurusAction):
         self.setText("All...")
         
     def actionTriggered(self):
-        #raise NotImplementedError('This action is not yet implemented')
         taurus_widget = self.parent()
-        from taurus.qt.qtgui.dialog.taurusconfigurationdialog import TaurusConfigurationDialog
-        d = TaurusConfigurationDialog()
+        from taurus.qt.qtgui.dialog.taurusconfigurationdialog import (
+            TaurusConfigurationDialog)
+        d = TaurusConfigurationDialog(taurus_widget)
         d.setModel(taurus_widget.getModelName())
         d.exec_()
 
